@@ -135,12 +135,7 @@ fetch_props_to_mail_item_cb (FetchItemsCallbackData *item_data, gpointer data)
 	}
 
 	if (delivery_date) {
-		NTTIME ntdate = { 0 };
-
-		ntdate = delivery_date->dwHighDateTime;
-		ntdate = ntdate << 32;
-		ntdate |= delivery_date->dwLowDateTime;
-		item->header.recieved_time = nt_time_to_unix(ntdate);
+		item->header.recieved_time = exchange_mapi_util_filetime_to_time_t (delivery_date);
 	}
 
 	if (flags && (*flags & MSGFLAG_READ) != 0)
@@ -407,6 +402,10 @@ mapi_mime_set_msg_headers (ExchangeMapiConnection *conn, CamelMimeMessage *msg,
 
 		g_object_unref (parser);
 		g_object_unref (part);
+	} else {
+		recieved_time = item->header.recieved_time;
+		actual_time = camel_header_decode_date (ctime(&recieved_time), &offset);
+		camel_mime_message_set_date (msg, actual_time, offset);
 	}
 
 	/* Overwrite headers if we have specific properties available*/
@@ -414,11 +413,6 @@ mapi_mime_set_msg_headers (ExchangeMapiConnection *conn, CamelMimeMessage *msg,
 	if (temp_str)
 		camel_mime_message_set_subject (msg, temp_str);
 
-	recieved_time = item->header.recieved_time;
-
-	actual_time = camel_header_decode_date (ctime(&recieved_time), &offset);
-	/* camel_mime_message_set_date (msg, actual_time, offset); */
-
 	if (item->header.from) {
 		if ((item->header.from_type != NULL) && !g_utf8_collate (item->header.from_type, "EX")) {
 			gchar *from_email;
